@@ -1,5 +1,4 @@
 from django.conf import settings
-
 from ..aws.sns_client_extended import SNSClientExtended
 from .event_base import EventBase
 
@@ -10,9 +9,10 @@ class EventBaseAws(EventBase):
     AWS_SECRET_ACCESS_KEY = settings.AWS_SECRET_ACCESS_KEY
     AWS_DEFAULT_REGION = settings.AWS_DEFAULT_REGION
     AWS_S3_QUEUE_STORAGE_NAME = settings.AWS_S3_QUEUE_STORAGE_NAME
-    AWS_SNS_TOPIC = settings.AWS_SNS_TOPIC
+    AWS_SNS_TOPIC = None
 
-    def dispatch(self, event_name, event_data):
+    def dispatch(self, event_name, event_data, message_group_id: str = None):
+        message_attributes = {'event_type': {'DataType': 'String', 'StringValue': event_name}}
         sns = SNSClientExtended(self.AWS_ACCESS_KEY_ID,
                                 self.AWS_SECRET_ACCESS_KEY,
                                 self.AWS_DEFAULT_REGION,
@@ -20,10 +20,6 @@ class EventBaseAws(EventBase):
         return sns.send_message(
             self.AWS_SNS_TOPIC,
             event_data,
-            message_attributes={
-                'event_type': {
-                    'DataType': 'String',
-                    'StringValue': event_name
-                }
-            }
-        )
+            message_attributes=message_attributes,
+            message_group_id=message_group_id,
+        )
\ No newline at end of file
