@@ -6,7 +6,7 @@ class EventProcessor(ABC):
     def __init__(self, **kwargs):
         self.data = kwargs.get('data')
         self.attributes = kwargs.get('attributes', {})
-        self.queue_code = kwargs.get('data')
+        self.queue_code = kwargs.get('queue_code')
 
     @abstractmethod
     def execute(self):
